<?php

if ( ! defined( 'ABSPATH' ) )
    exit;

Class In_Class_PandaSMS_Bildirimler
{
	function __construct()
	{
	    
		if(get_option('pandasms_adminAlert_newOrder_status')==1)
		add_action( 'woocommerce_thankyou', array( $this, 'admin_yeniSiparisBildirimi' ) );

        if(get_option('pandasms_customerAlert_shipped_status')==1)
		/** Sipariş durumu kargoya verildi yapıldığında bildirim mesajı gönder */
		add_action('urun_kargoya_verildi', array( $this, 'siparisDurumKontrol' ), 20, 4 );
		
		if(get_option('pandasms_customerAlert_newOrder_status')==1)
		add_action( 'woocommerce_thankyou', array( $this, 'musteri_yeniSiparisBildirimi' ) );

	}
	

	function sms_gonder($numaralar, $msgIcerik)
    {

        $body = [

            "veri" => [

                "kullaniciAdi"=>get_option("pandasms_username"),
                "sifre"=>get_option("pandasms_password"),
                "apiAnahtar"=>get_option("pandasms_apikey"),
                "originator"=>get_option("pandasms_originator"),
                "numaralar"=>$numaralar,
                "mesaj"=>$msgIcerik

            ]

        ];

        $body = wp_json_encode( $body );

        $options = [

            'body'              => $body,
            'headers'           => [
                'Content-type'  => 'application/json'
            ],
            'timeout' => 60,
            'data_format'       => 'body'

        ];

        $result_raw = wp_remote_post( 'https://api.pandasms.com/v3/mesajGonder', $options );

        $result = json_decode( $result_raw['body'] );

        return $result;


    }



    function sms_sorgula($gonderimNo)
    {

        $body = [

            "veri"  =>  [

                "kullaniciAdi"=>get_option("pandasms_username"),
                "sifre"=>get_option("pandasms_password"),
                "apiAnahtar"=>get_option("pandasms_apikey"),
                "gonderimNo"=>$gonderimNo,
                "msgGoster"=>true,

            ]

        ];


        $body = wp_json_encode( $body );

        $options = [

            'body'              => $body,
            'headers'           => [
                'Content-type'  => 'application/json'
            ],
            'timeout' => 60,
            'data_format'       => 'body'

        ];

        $result_raw = wp_remote_post( 'https://api.pandasms.com/v3/gonderimSorgula', $options );

        $result = json_decode( $result_raw['body'] );

        return $result;


    }

	
	/** Sipariş durumunun değiştiğini algıla */
	function siparisDurumKontrol( $order_id ){

			$this->kargoyaVerildiBildirimi($order_id);

	}



	function kargoyaVerildiBildirimi($order_id)
	{

		$orderDetails = wc_get_order($order_id);
		
		/** gelecek versiyonlarda değiştirilebilir yapılabilir */
		$billing_phone = $orderDetails->get_billing_phone();

        $entegre_intense_modul = esc_attr( get_option('_pandasms_entegre_intense_modul') );
        
        if($entegre_intense_modul=="intense-entegrasyon-kargo-takip"){
        	$shipping_company = get_post_meta( $order_id, '_intense_kargo_firmasi', true );
        	$shipping_number = get_post_meta( $order_id, '_intense_kargo_takip_no', true );
        }else{
        	$shipping_company = get_post_meta( $order_id, 'shipping_company', true );
        	$shipping_number = get_post_meta( $order_id, 'shipping_number', true );
        }

        if($shipping_company=="Kurye"){

            $kuryeMsgBildirimDurumu = esc_attr( get_option('pandasms_customerAlert_kurye_teslim_durum') );
            $kuryeMsgBildirimIcerik = esc_attr( get_option('pandasms_customerAlert_kurye_teslim_msg') );

            /** Kurye bildirimi aktifse, kuryelerde bildirim gönder. */
            if($kuryeMsgBildirimDurumu==1){

                $kuryeMsgBildirimIcerik = str_replace("{siparisNo}", $orderDetails->get_order_number(), $kuryeMsgBildirimIcerik);

                $messageContent = $kuryeMsgBildirimIcerik;

            }else{
                return False;
            }


        }else{

            $takipLinkOlustur = In_Class_PandaSMS_Helper::takipLinkOlustur($shipping_company,$shipping_number);

            $messageContent = get_option("pandasms_customerAlert_shipped_msg");

            $newMessageContent = str_replace("{siparisNo}", $orderDetails->get_order_number(), $messageContent);

            $sendShippingURLStatus = esc_attr( get_option('pandasms_customerAlert_send_shipping_url_status') );

            $messageContent = str_replace("{KargoBilgileri}", " ".$shipping_company." Takip No: ".$shipping_number, $newMessageContent);

            if($sendShippingURLStatus==1)
            {
                if($takipLinkOlustur!="")
                    $messageContent .= " - ".$takipLinkOlustur;
            }

        }

        /**
         * Mevcut gönderim kayıtlarını al.
         */
        $pandasms_bildirim_kayitlar = get_post_meta($order_id, "pandasms_bildirimler", true);

        if(empty($pandasms_bildirim_kayitlar)){

            $pandasms_bildirim_kayitlar = array();

        }

        /**
         * Mükerrer SMS gönderimini engelle.
         * Eğer daha önce başarılı bir gönderim olmuşsa, gönderim yapma.
         */
        if(array_key_exists("musteri_kargo", $pandasms_bildirim_kayitlar))
            if( $pandasms_bildirim_kayitlar["musteri_kargo"][0]>0 )
                return False;
        else
            return False;


        /**
         * SMS Gönder
         */
        $sms_gonderim = $this->sms_gonder( array($billing_phone), $messageContent );

        if($sms_gonderim>0){

            $pandasms_bildirim_kayitlar["musteri_kargo"][] =  $sms_gonderim->gonderimNo;

            /**
             * Gönderim bilgisini kaydet.
             */
            update_post_meta($order_id, "pandasms_bildirimler", $pandasms_bildirim_kayitlar);

        }



	}
	
	function musteri_yeniSiparisBildirimi($order_id)
	{

		$orderDetails = wc_get_order($order_id);

		/** gelecek versiyonlarda değiştirilebilir yapılabilir */
		$billing_phone = $orderDetails->get_billing_phone();

		$mesaj_icerik = get_option("pandasms_customerAlert_newOrder_msg");

		$mesaj_icerik_duzeltilmis = str_replace("{siparisNo}", $orderDetails->get_order_number(), $mesaj_icerik);


        /**
         * Mevcut gönderim kayıtlarını al.
         */
        $pandasms_bildirim_kayitlar = get_post_meta($order_id, "pandasms_bildirimler", true);

        if(empty($pandasms_bildirim_kayitlar)){

            $pandasms_bildirim_kayitlar = array();

        }

        /**
         * Mükerrer SMS gönderimini engelle.
         */
        if(array_key_exists("musteri_yeni_siparis", $pandasms_bildirim_kayitlar))
            if( $pandasms_bildirim_kayitlar["musteri_yeni_siparis"][0]>0 )
                return False;
            else
                return False;

        /**
         * SMS Gönder
         */
		$sms_gonderim = $this->sms_gonder( array($billing_phone), $mesaj_icerik_duzeltilmis );

		if($sms_gonderim>0){

            $pandasms_bildirim_kayitlar["musteri_yeni_siparis"][] =  $sms_gonderim->gonderimNo;


            /**
             * Gönderim bilgisini kaydet.
             */
            update_post_meta($order_id, "pandasms_bildirimler", $pandasms_bildirim_kayitlar);

        }


	}



    function admin_yeniSiparisBildirimi($order_id)
    {

        $siparis = wc_get_order( $order_id );

        $siparis_alindi_sms = get_option("pandasms_adminAlert_newOrder_msg");

        $siparis_alindi_sms_duzeltilmis = str_replace("{siparisNo}",$siparis->get_order_number(), $siparis_alindi_sms);

        /**
         * Mevcut gönderim kayıtlarını al.
         */
        $pandasms_bildirim_kayitlar = get_post_meta($order_id, "pandasms_bildirimler", true);

        if(empty($pandasms_bildirim_kayitlar)){

            $pandasms_bildirim_kayitlar = array();

        }

        /**
         * Mükerrer SMS gönderimini engelle.
         */
        if(array_key_exists("yonetici_yeni_siparis", $pandasms_bildirim_kayitlar))
            if( count($pandasms_bildirim_kayitlar["yonetici_yeni_siparis"])>0 )
                return False;
            else
                return False;

        /**
         * SMS Gönder
         */

        $numaralar_virgullu = get_option("admin_gsm");

        $numaralar_arr = explode(",", $numaralar_virgullu);


        $sms_gonderim = $this->sms_gonder( $numaralar_arr, $siparis_alindi_sms_duzeltilmis );

        if($sms_gonderim>0){

            $pandasms_bildirim_kayitlar["yonetici_yeni_siparis"][] =  $sms_gonderim->gonderimNo;

            /**
             * Gönderim bilgisini kaydet.
             */
            update_post_meta($order_id, "pandasms_bildirimler", $pandasms_bildirim_kayitlar);

        }


    }

}

new In_Class_PandaSMS_Bildirimler();